BlusaltLivenessResultResponse class

Constructors

BlusaltLivenessResultResponse({required BlusaltLivenessProcess blusaltLivenessProcess, Exception? exception, String? code, String? message, bool? isPassProcedureValidation, String? reference, BlusaltFacialComparisonData? comparisonData, BlusaltFaceDetectionData? faceDetectionData, DeviceMetaData? deviceMetaData})

Properties

blusaltLivenessProcess BlusaltLivenessProcess
final
code String?
final
comparisonData BlusaltFacialComparisonData?
final
deviceMetaData DeviceMetaData?
final
exception Exception?
final
faceDetectionData BlusaltFaceDetectionData?
final
hashCode int
The hash code for this object.
no setterinherited
isPassProcedureValidation bool?
final
message String?
final
reference String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited